package com.xdf.creative.module.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xdf.creative.base.params.creative.*;
import com.xdf.creative.base.service.impl.BaseServiceImpl;
import com.xdf.creative.base.vo.creative.*;
import com.xdf.creative.enums.*;
import com.xdf.creative.module.entity.*;
import com.xdf.creative.module.mapper.InfoContentMapper;
import com.xdf.creative.module.service.*;
import com.xdf.creative.util.StringUtil;
import com.xdf.creative.util.UUIDUtil;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.Serializable;
import java.util.Date;
import java.util.List;


/**
 * <p>
 * 信息内容 服务实现类
 * </p>
 *
 * @author lgw
 * @since 2020-03-09
 */
@Slf4j
@Service
@Transactional(rollbackFor = Exception.class)
public class InfoContentServiceImpl extends BaseServiceImpl<InfoContentMapper, InfoContent> implements InfoContentService {

    @Autowired
    private InfoContentMapper infoContentMapper;
    @Autowired
    private InfoDetailService infoDetailService;
    @Autowired
    private InfoAttachmentService infoAttachmentService;
    @Autowired
    private InfoUrlService infoUrlService;
    @Autowired
    private InfoBackService infoBackService;

    /**
     * t添加信息内容
     *
     * @param infoContentAddQueryParam
     * @return
     */
    @Override
    @Transactional
    public ApiResult addInfoContent(InfoContentAddQueryParam infoContentAddQueryParam) {
        InfoContent infoContent = new InfoContent();
        BeanUtils.copyProperties(infoContentAddQueryParam, infoContent);
        String foreignId = UUIDUtil.getUUID();
        infoContent.setForeignId(foreignId);
        InfoDetail infoDetail = infoContentAddQueryParam.getInfoDetail();
        //附表必须要有数据
        if (null == infoDetail) {
            return ApiResult.error(StatusCode.WEB_MANAGE_PUBLIC_DETAIL_BODY_NULL);
        }
        infoContent.setCreateUser(getUserId());
        infoContent.setDeleted(StateEnum.DISABLE.getKey());
        infoContent.setState(InfoStateTypeEnum.INFO_STATE_TYPE_DRAFT.getCode());
        infoContent.setIstop(StateEnum.DISABLE.getKey());
        infoContent.setOnlineType(StateEnum.ENABLE.getKey());
        infoContent.setId((long) 0);
        this.saveOrUpdate(infoContent);

        infoDetail.setForeignId(foreignId);
        infoDetailService.saveOrUpdate(infoDetail);
        //附件列表
        List<InfoAttachment> attachmentList = infoContentAddQueryParam.getAttachmentList();
        if (null != attachmentList) {
            for (InfoAttachment infoAttachment : attachmentList) {
                infoAttachment.setForeignId(foreignId);
                infoAttachmentService.saveOrUpdate(infoAttachment);
            }
        }
        List<InfoUrl> urlList = infoContentAddQueryParam.getUrlList();
        if (null != urlList) {
            for (InfoUrl infoUrl : urlList) {
                infoUrl.setForeignId(foreignId);
                infoUrlService.saveOrUpdate(infoUrl);
            }
        }

        return ApiResult.ok(infoContent.getTitle());
    }

    /**
     * 获取信息详情
     *
     * @param id
     * @return
     */
    @Override
    public ApiResult getInfoContent(Serializable id) {
        InfoContent infoContent = this.getById(id);
        if (null == infoContent) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        InfoContentAllQueryVo infoContentAllQueryVo = new InfoContentAllQueryVo();
        BeanUtils.copyProperties(infoContent, infoContentAllQueryVo);
        if (StringUtil.isNotEmpty(infoContent.getForeignId())) {
            InfoDetail infoDetail = infoDetailService.getOne(new QueryWrapper<InfoDetail>().eq("foreign_id", infoContent.getForeignId()));
            if (null != infoDetail) {
                infoContentAllQueryVo.setInfoDetail(infoDetail);
            }
            List<InfoAttachment> infoAttachmentList = infoAttachmentService.list(new QueryWrapper<InfoAttachment>().eq("foreign_id", infoContent.getForeignId()));
            if (infoAttachmentList.size() > 0) {
                infoContentAllQueryVo.setAttachmentList(infoAttachmentList);
            }
            List<InfoUrl> infoUrlList = infoUrlService.list(new QueryWrapper<InfoUrl>().eq("foreign_id", infoContent.getForeignId()));
            if (infoUrlList.size() > 0) {
                infoContentAllQueryVo.setUrlList(infoUrlList);
            }
        }
        return ApiResult.ok(infoContentAllQueryVo);
    }

    @Override
    public ApiResult getWebInfoContent(Serializable id) {
        InfoContent infoContent = this.getById(id);
        if (null == infoContent) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        InfoContentWebAllQueryVo infoContentWebAllQueryVo = new InfoContentWebAllQueryVo();
        BeanUtils.copyProperties(infoContent, infoContentWebAllQueryVo);
        if (StringUtil.isNotEmpty(infoContent.getForeignId())) {
            InfoDetail infoDetail = infoDetailService.getOne(new QueryWrapper<InfoDetail>().eq("foreign_id", infoContent.getForeignId()));
            if (null != infoDetail) {
                infoContentWebAllQueryVo.setInfoDetail(infoDetail);
            }
            List<InfoAttachment> infoAttachmentList = infoAttachmentService.list(new QueryWrapper<InfoAttachment>().eq("foreign_id", infoContent.getForeignId()));
            if (infoAttachmentList.size() > 0) {
                infoContentWebAllQueryVo.setAttachmentList(infoAttachmentList);
            }
            List<InfoUrl> infoUrlList = infoUrlService.list(new QueryWrapper<InfoUrl>().eq("foreign_id", infoContent.getForeignId()));
            if (infoUrlList.size() > 0) {
                infoContentWebAllQueryVo.setUrlList(infoUrlList);
            }
        }
        return ApiResult.ok(infoContentWebAllQueryVo);
    }


    @Override
    @Transactional
    public ApiResult updateInfoContent(InfoContentAddQueryParam infoContentAddQueryParam) {
        if (null == infoContentAddQueryParam.getId()) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        InfoContent infoContentNew = this.getById(infoContentAddQueryParam.getId());
        if (null == infoContentNew) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        BeanUtils.copyProperties(infoContentAddQueryParam, infoContentNew);
        InfoDetail infoDetail = infoContentAddQueryParam.getInfoDetail();
        if (null != infoDetail) {
            if (StringUtil.isEmpty(infoContentNew.getForeignId())) {
                return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
            }
            InfoDetail infoDetailNew = infoDetailService.getOne(new QueryWrapper<InfoDetail>().eq("foreign_id", infoContentAddQueryParam.getForeignId()));
            if (null != infoDetailNew) {
                if (null == infoDetailNew.getId()) {
                    return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
                }
                Long detailId = infoDetailNew.getId();
                BeanUtils.copyProperties(infoDetail, infoDetailNew);
                infoDetailNew.setId(detailId);
                infoDetailService.saveOrUpdate(infoDetailNew);
            }
        }
        this.updateById(infoContentNew);
        //附件先删除再添加
        List<InfoAttachment> infoAttachmentList = infoContentAddQueryParam.getAttachmentList();
        if (null != infoAttachmentList) {
            //不为空 等于0就删除
            infoAttachmentService.remove(new QueryWrapper<InfoAttachment>().eq("foreign_id", infoContentAddQueryParam.getForeignId()));
            if (infoAttachmentList.size() > 0) {
                for (InfoAttachment infoAttachment : infoAttachmentList) {
                    infoAttachment.setForeignId(infoContentAddQueryParam.getForeignId());
                    infoAttachmentService.save(infoAttachment);
                }
            }
        }
        //url先删除再添加
        List<InfoUrl> infoUrlList = infoContentAddQueryParam.getUrlList();
        if (null != infoUrlList) {
            //不为空 等于0就删除
            infoUrlService.remove(new QueryWrapper<InfoUrl>().eq("foreign_id", infoContentAddQueryParam.getForeignId()));
            if (infoUrlList.size() > 0) {
                for (InfoUrl infoUrl : infoUrlList) {
                    infoUrl.setForeignId(infoContentAddQueryParam.getForeignId());
                    infoUrlService.save(infoUrl);
                }
            }
        }
        return ApiResult.result(true);
    }

    /**
     * 初审信息
     *
     * @param infoContentAuditQueryParam
     * @return
     */
    @Override
    public ApiResult firstAuditInfo(InfoContentAuditQueryParam infoContentAuditQueryParam) {
        if (null == infoContentAuditQueryParam.getId()) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        InfoContent infoContent = this.getById(infoContentAuditQueryParam.getId());
        if (null == infoContent) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        if (!InfoStateTypeEnum.INFO_STATE_TYPE_FIRST_AUDIT.getCode().equals(infoContent.getState())) {
            return ApiResult.error(StatusCode.FORM_AUDIT_STATE_VERIFY);
        }
        if (InfoAuditTypeEnum.INFO_STATE_TYPE_AUDIT_PASS.getCode().equals(infoContentAuditQueryParam.getAuditState())) {
            infoContent.setState(InfoStateTypeEnum.INFO_STATE_TYPE_FINAL_AUDIT_STAY.getCode());
        } else if (InfoAuditTypeEnum.INFO_STATE_TYPE_AUDIT_BACK.getCode().equals(infoContentAuditQueryParam.getAuditState())) {
            if (StringUtil.isEmpty(infoContentAuditQueryParam.getBackIdea())) {
                return ApiResult.error(StatusCode.FORM_AUDIT_BACK_IDEA_VERIFY);
            }
            infoContent.setState(InfoStateTypeEnum.INFO_STATE_TYPE_FIRST_AUDIT_BACK.getCode());
            infoContent.setFirstAuditTime(new Date());
            infoContent.setFirstAuditUser(getUserId());

            InfoBack infoBack = new InfoBack();
            infoBack.setBackTime(new Date());
            infoBack.setBackType(InfoBackTypeEnum.INFO_STATE_TYPE_AUDIT_BACK_FIRST.getCode());
            infoBack.setForeignId(infoContent.getForeignId());
            infoBack.setReason(infoContentAuditQueryParam.getBackIdea());
            infoBack.setCreateUser(getUserId());
            infoBackService.saveOrUpdate(infoBack);
        } else if (InfoAuditTypeEnum.INFO_STATE_TYPE_AUDIT_NOPASS.getCode().equals(infoContentAuditQueryParam.getAuditState())) {
            infoContent.setState(InfoStateTypeEnum.INFO_STATE_TYPE_FIRST_AUDIT_NOPASS.getCode());
        }
        infoContent.setUpdateTime(new Date());
        infoContent.setFirstAuditTime(new Date());
        infoContent.setFirstAuditUser(getUserId());
        this.saveOrUpdate(infoContent);
        return ApiResult.ok();
    }

    /**
     * 终审
     *
     * @param infoContentAuditQueryParam
     * @return
     */
    @Override
    public ApiResult finalAuditInfo(InfoContentAuditQueryParam infoContentAuditQueryParam) {
        if (null == infoContentAuditQueryParam.getId()) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        InfoContent infoContent = this.getById(infoContentAuditQueryParam.getId());
        if (null == infoContent) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        if (!InfoStateTypeEnum.INFO_STATE_TYPE_FINAL_AUDIT_STAY.getCode().equals(infoContent.getState())) {
            return ApiResult.error(StatusCode.FORM_AUDIT_STATE_VERIFY);
        }
        if (InfoAuditTypeEnum.INFO_STATE_TYPE_AUDIT_PASS.getCode().equals(infoContentAuditQueryParam.getAuditState())) {
            infoContent.setState(InfoStateTypeEnum.INFO_STATE_TYPE_FINAL_AUDIT_PASS.getCode());
        } else if (InfoAuditTypeEnum.INFO_STATE_TYPE_AUDIT_BACK.getCode().equals(infoContentAuditQueryParam.getAuditState())) {
            if (StringUtil.isEmpty(infoContentAuditQueryParam.getBackIdea())) {
                return ApiResult.error(StatusCode.FORM_AUDIT_BACK_IDEA_VERIFY);
            }
            infoContent.setState(InfoStateTypeEnum.INFO_STATE_TYPE_FINAL_AUDIT_BACK.getCode());
            infoContent.setFirstAuditTime(new Date());
            infoContent.setFirstAuditUser(getUserId());

            InfoBack infoBack = new InfoBack();
            infoBack.setBackTime(new Date());
            infoBack.setBackType(InfoBackTypeEnum.INFO_STATE_TYPE_AUDIT_BACK_FINAL.getCode());
            infoBack.setForeignId(infoContent.getForeignId());
            infoBack.setReason(infoContentAuditQueryParam.getBackIdea());
            infoBack.setCreateUser(getUserId());
            infoBackService.saveOrUpdate(infoBack);
        } else if (InfoAuditTypeEnum.INFO_STATE_TYPE_AUDIT_NOPASS.getCode().equals(infoContentAuditQueryParam.getAuditState())) {
            infoContent.setState(InfoStateTypeEnum.INFO_STATE_TYPE_FINAL_AUDIT_NOPASS.getCode());
        }
        infoContent.setUpdateTime(new Date());
        infoContent.setFinalAuditTime(new Date());
        infoContent.setFinalAuditUser(getUserId());
        this.saveOrUpdate(infoContent);
        return ApiResult.ok();
    }

    /**
     * 提交信息内容
     *
     * @param infoContentAuditQueryParam
     * @return
     */
    @Override
    public ApiResult commitInfoContent(InfoContentAuditQueryParam infoContentAuditQueryParam) {
        if (null == infoContentAuditQueryParam.getId()) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        InfoContent infoContent = this.getById(infoContentAuditQueryParam.getId());
        if (null == infoContent) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        if (!InfoStateTypeEnum.INFO_STATE_TYPE_DRAFT.getCode().equals(infoContent.getState())) {
            return ApiResult.error(StatusCode.FORM_UPDATE_STATE_VERIFY);
        }
        infoContent.setSubmitTime(new Date());
        infoContent.setState(InfoStateTypeEnum.INFO_STATE_TYPE_FIRST_AUDIT.getCode());
        infoContent.setUpdateTime(new Date());
        this.saveOrUpdate(infoContent);
        return ApiResult.ok();
    }

    /**
     * 信息上下线
     *
     * @param infoContentAuditQueryParam
     * @return
     */
    @Override
    public ApiResult onlineInfoContent(InfoContentAuditQueryParam infoContentAuditQueryParam) {
        if (null == infoContentAuditQueryParam.getId()) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        InfoContent infoContent = this.getById(infoContentAuditQueryParam.getId());
        if (null == infoContent) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        if (!InfoStateTypeEnum.INFO_STATE_TYPE_FINAL_AUDIT_PASS.getCode().equals(infoContent.getState())) {
            return ApiResult.error(StatusCode.FORM_AUDIT_FINAL_AUDIT_PASS_VERIFY);
        }
        if (infoContent.getOnlineType().equals(InfoOnlineStateEnum.PUBLIC_INFO_STATE_ONLINE.getCode())) {
            infoContent.setOnlineType(InfoOnlineStateEnum.PUBLIC_INFO_STATE_OFFLINE.getCode());
        } else {
            infoContent.setOnlineType(InfoOnlineStateEnum.PUBLIC_INFO_STATE_ONLINE.getCode());
        }
        infoContent.setUpdateTime(new Date());
        this.saveOrUpdate(infoContent);
        return ApiResult.ok();
    }


    /**
     * 是否置顶
     *
     * @param infoContentAuditQueryParam
     * @return
     */
    @Override
    public ApiResult isTopInfoContent(InfoContentAuditQueryParam infoContentAuditQueryParam) {
        if (null == infoContentAuditQueryParam.getId()) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        InfoContent infoContent = this.getById(infoContentAuditQueryParam.getId());
        if (null == infoContent) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        if (!InfoStateTypeEnum.INFO_STATE_TYPE_FINAL_AUDIT_PASS.getCode().equals(infoContent.getState())) {
            return ApiResult.error(StatusCode.FORM_AUDIT_FINAL_AUDIT_PASS_VERIFY);
        }
        if (infoContent.getIstop().equals(StateEnum.ENABLE.getKey())) {
            infoContent.setIstop(StateEnum.DISABLE.getKey());
        } else {
            infoContent.setIstop(StateEnum.ENABLE.getKey());
            infoContent.setIstopTime(new Date());
        }
        infoContent.setUpdateTime(new Date());
        this.saveOrUpdate(infoContent);
        return ApiResult.ok();
    }

    /**
     * 修改排序
     *
     * @param infoContentAuditQueryParam
     * @return
     */
    @Override
    public ApiResult updateInfoSort(InfoContentAuditQueryParam infoContentAuditQueryParam) {
        if (null == infoContentAuditQueryParam.getId()) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        if (null == infoContentAuditQueryParam.getSort()) {
            return ApiResult.error(StatusCode.FORM_INFO_CONTENT_SORT_VERIFY);
        }
        InfoContent infoContent = this.getById(infoContentAuditQueryParam.getId());
        if (null == infoContent) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        infoContent.setSort(infoContentAuditQueryParam.getSort());
        infoContent.setUpdateTime(new Date());
        this.saveOrUpdate(infoContent);
        return ApiResult.ok();
    }

    /**
     * 信息是否置为回收站(还原)
     *
     * @param infoContentAuditQueryParam
     * @return
     */
    @Override
    public ApiResult recycleInfoContent(InfoContentAuditQueryParam infoContentAuditQueryParam) {
        if (null == infoContentAuditQueryParam.getId()) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        InfoContent infoContent = this.getById(infoContentAuditQueryParam.getId());
        if (null == infoContent) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        if (StateEnum.DISABLE.getKey().equals(infoContent.getDeleted())) {
            //如果置入回收站 要先判断 信息状态是不是草稿、退回
            if(!infoContent.getState().equals(InfoStateTypeEnum.INFO_STATE_TYPE_DRAFT.getCode())&&
                    !infoContent.getState().equals(InfoStateTypeEnum.INFO_STATE_TYPE_FINAL_AUDIT_BACK.getCode())&&
                    !infoContent.getState().equals(InfoStateTypeEnum.INFO_STATE_TYPE_FIRST_AUDIT_BACK.getCode())){
                return ApiResult.fail("只能删除草稿、退回状态的信息！");
            }
            infoContent.setDeleted(StateEnum.ENABLE.getKey());
        } else {
            infoContent.setDeleted(StateEnum.DISABLE.getKey());
        }
        infoContent.setUpdateTime(new Date());
        this.saveOrUpdate(infoContent);
        return ApiResult.ok();
    }

    /**
     * 回收站内彻底删除信息
     *
     * @param infoContentAuditQueryParam
     * @return
     */
    @Override
    @Transactional
    public ApiResult deleteInfoManageContent(InfoContentAuditQueryParam infoContentAuditQueryParam) {
        if (null == infoContentAuditQueryParam.getId()) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        InfoContent infoContent = this.getById(infoContentAuditQueryParam.getId());
        if (null == infoContent) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        if (!StateEnum.ENABLE.getKey().equals(infoContent.getDeleted())) {
            return ApiResult.error(StatusCode.FORM_INFO_CONTENT_DELETE_VERIFY);
        }
        //删除信息
        String foreignId = infoContent.getForeignId();
        if (StringUtil.isEmpty(foreignId)) {
            return ApiResult.error(StatusCode.FORM_AUTH_UPDATE_VERIFY_ERROR);
        }
        infoDetailService.remove(new QueryWrapper<InfoDetail>().eq("foreign_id", infoContent.getForeignId()));
        infoAttachmentService.remove(new QueryWrapper<InfoAttachment>().eq("foreign_id", infoContent.getForeignId()));
        infoUrlService.remove(new QueryWrapper<InfoUrl>().eq("foreign_id", infoContent.getForeignId()));
        infoBackService.remove(new QueryWrapper<InfoBack>().eq("foreign_id", infoContent.getForeignId()));
        this.removeById(infoContent.getId());
        return ApiResult.ok();
    }




    /**
     * 首页显示新闻信息
     * @param infoContentHomePageQueryParam
     * @return
     */
    @Override
    public ApiResult getHomePageInfo(InfoContentHomePageQueryParam infoContentHomePageQueryParam) {
        return ApiResult.ok(infoContentMapper.getHomePageInfo(infoContentHomePageQueryParam));
    }


    /**
     * 首页搜索信息
     * @param infoContentWebSearchQueryParam
     * @return
     * @throws Exception
     */
    @Override
    public PageTool<InfoContentWebSearchQueryVo> getSearchWebInfo(InfoContentWebSearchQueryParam infoContentWebSearchQueryParam) throws Exception {
        Page page = setPageParam(infoContentWebSearchQueryParam);
        IPage<InfoContentWebSearchQueryVo> iPage = infoContentMapper.getSearchWebInfo(page, infoContentWebSearchQueryParam);
        return new PageTool(iPage);
    }

    /**
     * 发布列表
     * @param infoContentBackSearchQueryParam
     * @return
     * @throws Exception
     */
    @Override
    public PageTool<InfoContentBackSearchQueryVo> getInfoContentByAdd(InfoContentBackSearchQueryParam infoContentBackSearchQueryParam) throws Exception {
        Page page = setPageParam(infoContentBackSearchQueryParam);
        IPage<InfoContentBackSearchQueryVo> iPage = infoContentMapper.getInfoContentByAdd(page, infoContentBackSearchQueryParam);
        return new PageTool(iPage);
    }

    /**
     * 初审列表
     * @param infoContentBackSearchQueryParam
     * @return
     * @throws Exception
     */
    @Override
    public PageTool<InfoContentBackSearchQueryVo> getInfoContentByFirstAudit(InfoContentBackSearchQueryParam infoContentBackSearchQueryParam) throws Exception {
        Page page = setPageParam(infoContentBackSearchQueryParam);
        IPage<InfoContentBackSearchQueryVo> iPage = infoContentMapper.getInfoContentByFirstAudit(page, infoContentBackSearchQueryParam);
        return new PageTool(iPage);
    }

    /**
     * 终审列表
     * @param infoContentBackSearchQueryParam
     * @return
     * @throws Exception
     */
    @Override
    public PageTool<InfoContentBackSearchQueryVo> getInfoContentByFinalAudit(InfoContentBackSearchQueryParam infoContentBackSearchQueryParam) throws Exception {
        Page page = setPageParam(infoContentBackSearchQueryParam);
        IPage<InfoContentBackSearchQueryVo> iPage = infoContentMapper.getInfoContentByFinalAudit(page, infoContentBackSearchQueryParam);
        return new PageTool(iPage);
    }

    @Override
    public PageTool<InfoContentRecycleSearchQueryVo> getInfoContentByRecycle(InfoContentBackSearchQueryParam infoContentBackSearchQueryParam) throws Exception {
        Page page = setPageParam(infoContentBackSearchQueryParam);
        IPage<InfoContentRecycleSearchQueryVo> iPage = infoContentMapper.getInfoContentByRecycle(page, infoContentBackSearchQueryParam);
        return new PageTool(iPage);
    }


    @Override
    public InfoContentQueryVo getInfoContentById(Serializable id) throws Exception {
        return infoContentMapper.getInfoContentById(id);
    }

    @Override
    public PageTool<InfoContentQueryVo> getInfoContentPageList(InfoContentQueryParam infoContentQueryParam) throws Exception {
        Page page = setPageParam(infoContentQueryParam);
        IPage<InfoContentQueryVo> iPage = infoContentMapper.getInfoContentPageList(page, infoContentQueryParam);
        return new PageTool(iPage);
    }

}
